@@ -285,13 +285,9 @@ GRAVITY_DIGITS = (
     # Why don't Python and C agree more closely?
     4 if not accelerated
 
-    # Insist on very high precision on my Linux laptop, to signal me if
-    # some future adjustment subtlely changes the library's results.
-    else 12 if platform.system() == 'Linux' and platform.machine() == 'x86_64'
-
-    # Otherwise, reduce our expectations.  Note that at least 6 digits
-    # past the decimal point are necessary to let the test distinguish
-    # between WSG72OLD and WGS72.  See:
+    # Otherwise, try 10 digits.  Note that at least 6 digits past the
+    # decimal point are necessary to let the test distinguish between
+    # WSG72OLD and WGS72.  See:
     # https://github.com/conda-forge/sgp4-feedstock/pull/19
     # https://github.com/brandon-rhodes/python-sgp4/issues/69
     else 10
@@ -533,6 +529,7 @@ def test_satrec_against_tcppver_using_julian_dates():
         jd = satrec.jdsatepoch + whole
         fr = satrec.jdsatepochF + fraction
         e, r, v = satrec.sgp4(jd, fr)
+        assert e == satrec.error
         return e, r, v
 
     run_satellite_against_tcppver(Satrec.twoline2rv, invoke, [1,1,6,6,4,3,6])
@@ -541,6 +538,7 @@ def test_satrec_against_tcppver_using_tsince():
 
     def invoke(satrec, tsince):
         e, r, v = satrec.sgp4_tsince(tsince)
+        assert e == satrec.error
         return e, r, v
 
     run_satellite_against_tcppver(Satrec.twoline2rv, invoke, [1,1,6,6,4,3,6])
@@ -763,13 +761,9 @@ def test_omm_csv_matches_old_tle():
     assert_satellites_match(sat1, sat2)
 
 def assert_satellites_match(sat1, sat2):
-    todo = {'whichconst'}
-
     for attr in dir(sat1):
         if attr.startswith('_'):
             continue
-        if attr in todo:
-            continue
         value1 = getattr(sat1, attr, None)
         if value1 is None:
             continue
